// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSANE_VERSION_H
#define KSANE_VERSION_H

#define KSANE_VERSION_STRING "26.07.80"
#define KSANE_VERSION_MAJOR 26
#define KSANE_VERSION_MINOR 7
#define KSANE_VERSION_PATCH 80
#define KSANE_VERSION ((26<<16)|(7<<8)|(80))

#endif
